{% load i18n leprikon_tags %}

<p>
    {{ object.subject.subject_type.name | first_upper }}: {{ object.subject.name }}<br/>
    {% if object.subject.registration_type_participants %}
        {% if object.all_participants|length > 1 %}{% trans 'Participants' %}{% else %}{% trans 'Participant' %}{% endif %}:
        {{ object.all_participants|comma_separated }}<br/>
    {% elif object.subject.registration_type_groups %}
        {% trans 'Contact person' %}: {{ object.group.first_name }}
        {% if object.group.name %}<br/>{% trans 'Group name' %}: {{ object.group.name }}{% endif %}
    {% endif %}
</p>

<p>
    {% trans 'You may download the registration in PDF using the following link:' %}<br/>
    <a href="{{ site.url }}{{ object.get_absolute_url }}">
        {{ site.url }}{{ object.get_absolute_url }}
    </a>
</p>
